%define major 11
%define libname   %mklibname opendkim %{major}
%define develname %mklibname opendkim -d
%define bigname OpenDKIM
%define bigversion 2.11.0-Beta2
%define postfixdir %{_var}/spool/postfix

Name:       opendkim
Version:    2.11.0
Release:    %mkrel 0.beta2.6
Summary:    DomainKeys Identified Mail (DKIM) milter to sign and/or verify mail
Group:      System/Servers
License:    BSD and Sendmail
URL:        http://www.opendkim.org/
Source0:    https://github.com/trusteddomainproject/%{bigname}/archive/refs/tags/%{bigversion}.tar.gz
Source1:    README.urpmi
Source2:    external_hosts.conf
Source3:    internal_hosts.conf
Source4:    key_table.conf
Source5:    signing_table.conf
Source6:    opendkim.tmpfiles
Patch0:     opendkim-2.10.3-fix-pidfile-path.patch
Patch1:     opendkim-2.10.3-change-default-crypto-settings.patch
BuildRequires: sendmail-devel
BuildRequires: db-devel
BuildRequires: pkgconfig(openssl)
BuildRequires: pkgconfig(libbsd)
BuildRequires: pkgconfig(libmemcached)
BuildRequires: pkgconfig(opendbx)

%description
OpenDKIM allows signing and/or verification of email through an open source
library that implements the DKIM service, plus a milter-based filter
application that can plug in to any milter-aware MTA, including sendmail,
Postfix, or any other MTA that supports the milter protocol.

%package -n %{libname}
Summary: An open source DKIM library
Group: System/Servers

%description -n %{libname}
This package contains the library files required for running services built
using libopendkim.

%package -n %{develname}
Summary: Development files for lib%{name}
Group: Development/Other

%description -n %{develname}
This package contains the static libraries, headers, and other support files
required for developing applications against libopendkim.

%prep
%autosetup -p 1 -n %{bigname}-%{bigversion}

%build
autoreconf -f -i
# Always use system libtool instead of pacakge-provided one to
# properly handle 32 versus 64 bit detection and settings
#define LIBTOOL LIBTOOL=`which libtool`

%configure --with-libmemcached --with-db --with-odbx --enable-query_cache

# Remove rpath
%{__sed} -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
%{__sed} -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
%make_build

%install
%make_install
install -d %{buildroot}%{_sysconfdir}
install -m 0755 contrib/init/redhat/%{name}-default-keygen %{buildroot}%{_sbindir}/%{name}-default-keygen

install -d -m 0755 %{buildroot}%{_unitdir}
install -m 0644 contrib/systemd/%{name}.service %{buildroot}%{_unitdir}/%{name}.service
perl -pi -e 's|^(ExecReload=)|ExecStartPost=+%{_bindir}/systemd-tmpfiles --create %{_tmpfilesdir}/%{name}.conf\n$1|' %{buildroot}%{_unitdir}/%{name}.service

install -m 0644 opendkim/%{name}.conf.sample %{buildroot}%{_sysconfdir}/%{name}.conf
perl -pi -e 's|^# (Canonicalization)(\t+)simple/simple|$1$2relaxed/relaxed|;
s|^# (PidFile\t+)filename|$1%{_rundir}/%{name}/%{name}.pid|;
s|^(KeyFile)(\t+)/var/db/dkim/example.private|$1$2%{_sysconfdir}/%{name}/keys/default.private|;
s|^(Selector)(\t+)my-selector-name|$1$2default|;
s|^(Socket)(\t+)inet:port\@localhost|# $1$2inet:8891\@localhost\n$1$2local:%{postfixdir}%{_rundir}/%{name}/%{name}.sock|;
s|^# (OverSignHeaders\t+)(header1,header2,...)|# $1$2\n$1\tFrom|;
s|^(# KeyTable\t+)dataset|$1%{_sysconfdir}/%{name}/key_table.conf|;
s|^(# SigningTable\t+)filename|$1refile:%{_sysconfdir}/%{name}/signing_table.conf|;
s|^(# ExternalIgnoreList\t+)filename|$1refile:%{_sysconfdir}/%{name}/external_hosts.conf|;
s|^# (InternalHosts\t+)dataset|$1refile:%{_sysconfdir}/%{name}/internal_hosts.conf|;
s|^(Syslog\t+Yes)|# $1|;
s|^(# UMask\t+)(022)$|${1}0${2}|;
' %{buildroot}%{_sysconfdir}/%{name}.conf

install -m 0644 %{SOURCE1} README.urpmi

install -d %{buildroot}%{_sysconfdir}/%{name}
install -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/%{name}/external_hosts.conf
install -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}/internal_hosts.conf
install -m 0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/%{name}/key_table.conf
install -m 0644 %{SOURCE5} %{buildroot}%{_sysconfdir}/%{name}/signing_table.conf

install -p -d %{buildroot}%{_tmpfilesdir}
install -m 0644 %{SOURCE6} %{buildroot}%{_tmpfilesdir}/%{name}.conf

rm -rf %{buildroot}%{_prefix}/share/doc/%{name}
rm -f %{buildroot}%{_libdir}/*.a
rm -f %{buildroot}%{_libdir}/*.la

install -d %{buildroot}%{_localstatedir}/spool/%{name}
install -d %{buildroot}/run/%{name}
install -d %{buildroot}%{_sysconfdir}/%{name}
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/keys

install -m 0755 stats/%{name}-reportstats %{buildroot}%{_prefix}/sbin/%{name}-reportstats
sed -i \
    -e 's|^OPENDKIMSTATSDIR="/var/db/%{name}"|OPENDKIMSTATSDIR="%{_localstatedir}/spool/%{name}"|g' \
    -e 's|^OPENDKIMDATOWNER="mailnull:mailnull"|OPENDKIMDATOWNER="%{name}:%{name}"|g' \
     %{buildroot}%{_prefix}/sbin/%{name}-reportstats

chmod 0644 contrib/convert/convert_keylist.sh

%pre
%_pre_useradd opendkim /run/opendkim /bin/false

%post
%_post_service %{name}
%_tmpfilescreate %{name}

# Generate default key on install
if [ "$1" -eq "1" ]; then
	%{_sbindir}/opendkim-default-keygen > /dev/null 2>&1 || /bin/true
fi

%preun
%_preun_service %{name}

%files
%doc LICENSE LICENSE.Sendmail
%doc FEATURES KNOWNBUGS RELEASE_NOTES RELEASE_NOTES.Sendmail INSTALL
%doc contrib/convert/convert_keylist.sh %{name}/*.sample
%doc %{name}/%{name}.conf.simple-verify %{name}/%{name}.conf.simple
%doc %{name}/README contrib/lua/*.lua
%doc README.urpmi
%config(noreplace) %{_sysconfdir}/%{name}.conf
%config(noreplace) %{_tmpfilesdir}/%{name}.conf
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/keys
%config(noreplace) %attr(0640,root,opendkim) %{_sysconfdir}/%{name}/external_hosts.conf
%config(noreplace) %attr(0640,root,opendkim) %{_sysconfdir}/%{name}/internal_hosts.conf
%config(noreplace) %attr(0640,root,opendkim) %{_sysconfdir}/%{name}/key_table.conf
%config(noreplace) %attr(0640,root,opendkim) %{_sysconfdir}/%{name}/signing_table.conf
%{_sbindir}/*
%{_mandir}/*/*
%dir %attr(-,opendkim,opendkim) %{_localstatedir}/spool/%{name}
%{_unitdir}/%{name}.service

%files -n %{libname}
%doc LICENSE LICENSE.Sendmail
%doc README
%{_libdir}/lib%{name}.so.*

%files -n %{develname}
%doc LICENSE LICENSE.Sendmail
%doc lib%{name}/docs/*.html
%{_includedir}/%{name}
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc


%changelog
* Sat Jun 28 2025 umeabot <umeabot> 2.11.0-0.beta2.6.mga10
+ Revision: 2221177
- Mageia 10 Mass Rebuild

* Wed Jan 31 2024 rapsys <rapsys> 2.11.0-0.beta2.5.mga10
+ Revision: 2036415
- Fix unreplaced values
- Fix unreplaced values

* Wed Jan 31 2024 rapsys <rapsys> 2.11.0-0.beta2.4.mga10
+ Revision: 2036413
- Fix commented out default umask

* Wed Jan 31 2024 rapsys <rapsys> 2.11.0-0.beta2.3.mga10
+ Revision: 2036398
- Move README.urpmi and config files into separates files
- Move README.urpmi and config files into separates files

* Sat Oct 21 2023 rapsys <rapsys> 2.11.0-0.beta2.2.mga10
+ Revision: 1999982
- Separate external and internal hosts config files
- Separate external and internal hosts config files

* Sat Oct 21 2023 rapsys <rapsys> 2.11.0-0.beta2.1.mga10
+ Revision: 1999970
- Version 2-11-0-Beta2
- Version 2-11-0-Beta2
- Version 2-11-0-Beta2
- Version 2-11-0-Beta2

* Mon Jul 10 2023 rapsys <rapsys> 2.10.3-18.mga9
+ Revision: 1963815
- Bump release

* Mon Jul 10 2023 rapsys <rapsys> 2.10.3-17.mga9
+ Revision: 1963811
- Remove useless sysconfig file which redefines defaults
- Fix unneeded backslash in README.urpmi
- Limit strict permission to key files
- Fix tmpfiles.d to have a config alike other services (named, mysql, memcached, httpd, etc)
- Make keys directory owned by root
- Revert to 2048 bit as NIST 800-177 recomands
- Revert config to tabs

* Mon Jun 26 2023 rapsys <rapsys> 2.10.3-16.mga9
+ Revision: 1963125
- Cleanup README.urpmi
- Fix double listed opendkim-default-keygen file

* Mon Jun 26 2023 rapsys <rapsys> 2.10.3-15.mga9
+ Revision: 1963120
- Fix tmpfiles
  Fix naming type in config
  Switch to local socket

* Sun Apr 03 2022 umeabot <umeabot> 2.10.3-14.mga9
+ Revision: 1841497
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 2.10.3-13.mga9
+ Revision: 1747583
- rebuild for openssl 3.0.0

* Sun Dec 20 2020 guillomovitch <guillomovitch> 2.10.3-12.mga8
+ Revision: 1661676
- tune default crypto settings based on NIST preconisation, and a Debian patch

* Sat Dec 19 2020 guillomovitch <guillomovitch> 2.10.3-11.mga8
+ Revision: 1661297
- automatically create default pair of keys on install
- make temp dir group-readable
- no need to pass options for default values
- enable query cache support
- enforce upstream software name in description
- not need to give configuration file ownership to opendkim user,
  read access is enough
- fix invalid user shell
- fix post/preun scripts
- revert undiscussed changes

* Fri Dec 11 2020 rapsys <rapsys> 2.10.3-10.mga8
+ Revision: 1655389
- Enable by default keytable, signingtable, externalignorelist and internalhosts
- Switch to sign and verify by default
  Improve README.urpmi

* Fri Dec 11 2020 rapsys <rapsys> 2.10.3-9.mga8
+ Revision: 1655382
- Fix too permissive write access in /etc/opendkim
  Swith to 4096 key by default
  Auto-generate default key on install
  Cleanup useless variables from service
  Remove header reporting software version
  Fix user invalid shell binary
  Cleanup README.urpmi

* Sat Feb 15 2020 umeabot <umeabot> 2.10.3-8.mga8
+ Revision: 1526868
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std

* Thu Jul 04 2019 guillomovitch <guillomovitch> 2.10.3-7.mga8
+ Revision: 1418617
- use /run instead of /var/run in configuration

* Sun Sep 23 2018 umeabot <umeabot> 2.10.3-6.mga7
+ Revision: 1300010
- Mageia 7 Mass Rebuild

* Sat Aug 05 2017 guillomovitch <guillomovitch> 2.10.3-5.mga7
+ Revision: 1135113
- rebuild for latest openssl

* Thu Mar 03 2016 umeabot <umeabot> 2.10.3-4.mga6
+ Revision: 983851
- Rebuild for openssl

* Fri Feb 26 2016 luigiwalser <luigiwalser> 2.10.3-3.mga6
+ Revision: 979745
- rebuild with configure2_5x

* Sun Dec 13 2015 guillomovitch <guillomovitch> 2.10.3-2.mga6
+ Revision: 910233
- bump release
- imported package opendkim

